## Better-Twitter
A simple python tool that makes your twitter timeline much better.

### Installation
```
pip install better-twitter
```

### Get started
##### Using in command line
To block multiple users of a file:
```
python3 better-twitter --block-file test_file.csv
```
Note: The csv file should have two columns named `user_id` and `screen_name`.